@@ -31,7 +31,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# $Header: /cvsroot/nsnam/ns-2/tcl/lib/ns-mobilenode.tcl,v 1.56 2007/01/30 05:00:51 tom_henderson Exp $
+# $Header: /cvsroot/nsnam/ns-2/tcl/lib/ns-mobilenode.tcl,v 1.60 2009/01/15 06:23:49 tom_henderson Exp $
 #
 # Ported from CMU-Monarch project's mobility extensions -Padma, 10/98.
 #
@@ -186,6 +186,12 @@ Node/MobileNode instproc add-target { agent port } {
 		[$self set imep_(0)] rtagent $agent
 	}
 	
+	# Special processing for AOMDV
+	set aomdvonly [string first "AOMDV" [$agent info class]] 
+	if {$aomdvonly != -1 } {
+		$agent if-queue [$self set ifq_(0)]   ;# ifq between LL and MAC
+	}
+	
 	# Special processing for AODV
 	set aodvonly [string first "AODV" [$agent info class]] 
 	if {$aodvonly != -1 } {
@@ -487,7 +493,10 @@ Node/MobileNode instproc add-interface { channel pmodel lltype mactype qtype qle
 	}
 
 	set god_ [God instance]
-        if {$mactype == "Mac/802_11"} {
+    if {$mactype == "Mac/802_11Ext"} {
+		$mac nodes [$god_ num_nodes]
+	}
+    if {$mactype == "Mac/802_11"} {
 		$mac nodes [$god_ num_nodes]
 	}
 	#
@@ -532,6 +541,38 @@ Node/MobileNode instproc add-interface { channel pmodel lltype mactype qtype qle
 	$topo channel $channel
 	# ============================================================
 
+	if { [Simulator set PhyTrace_] == "ON" } {
+		#
+		# Trace Dropped Packets
+		#
+		if {$imepflag != ""} {
+			set drpPhyT [$self mobility-trace Drop "PHY"]
+		} else {
+			set drpPhyT [cmu-trace Drop "PHY" $self]
+		}
+		$netif drop-target $drpPhyT
+		if { $namfp != "" } {
+			$drpPhyT namattach $namfp
+		}
+
+		#
+		# Trace Sent Packets
+		#
+        if {$imepflag != ""} {
+            set sndPhyT [$self mobility-trace Send "PHY"]
+        } else {
+            set sndPhyT [cmu-trace Send "PHY" $self]
+        }
+        $sndPhyT target $channel
+        $netif down-target $sndPhyT
+        if { $namfp != "" } {
+            $sndPhyT namattach $namfp
+        }
+        
+	} else {
+		$netif drop-target [$ns set nullAgent_]
+	}
+
 	if { [Simulator set MacTrace_] == "ON" } {
 		#
 		# Trace RTS/CTS/ACK Packets
